import Reference from './reference';
import BoundingSphere from './boundingsphere';
import BoundingShape from './boundingshape';
/**
 * The model information structure.
 */
export default class ModelHeader {
    constructor() {
        this.version = -1;
        this.modelName = new Reference();
        this.flags = 0;
        this.sequences = new Reference();
        this.stc = new Reference();
        this.stg = new Reference();
        this.unknown0 = 0;
        this.unknown1 = 0;
        this.unknown2 = 0;
        this.unknown3 = 0;
        this.sts = new Reference();
        this.bones = new Reference();
        this.numberOfBonesToCheckForSkin = 0;
        this.vertexFlags = 0;
        this.vertices = new Reference();
        this.divisions = new Reference();
        this.boneLookup = new Reference();
        this.boundings = new BoundingSphere();
        this.unknown4To20 = new Uint32Array(16);
        this.attachmentPoints = new Reference();
        this.attachmentPointAddons = new Reference();
        this.ligts = new Reference();
        this.shbxData = new Reference();
        this.cameras = new Reference();
        this.unknown21 = new Reference();
        this.materialReferences = new Reference();
        this.materials = [];
        this.particleEmitters = new Reference();
        this.particleEmitterCopies = new Reference();
        this.ribbonEmitters = new Reference();
        this.projections = new Reference();
        this.forces = new Reference();
        this.warps = new Reference();
        this.unknown22 = new Reference();
        this.rigidBodies = new Reference();
        this.unknown23 = new Reference();
        this.physicsJoints = new Reference();
        this.clothBehavior = new Reference();
        this.unknown24 = new Reference();
        this.ikjtData = new Reference();
        this.unknown25 = new Reference();
        this.unknown26 = new Reference();
        this.partsOfTurrentBehaviors = new Reference();
        this.turrentBehaviors = new Reference();
        this.absoluteInverseBoneRestPositions = new Reference();
        this.tightHitTest = new BoundingShape();
        this.fuzzyHitTestObjects = new Reference();
        this.attachmentVolumes = new Reference();
        this.attachmentVolumesAddon0 = new Reference();
        this.attachmentVolumesAddon1 = new Reference();
        this.billboardBehaviors = new Reference();
        this.tmdData = new Reference();
        this.unknown27 = 0;
        this.unknown28 = new Reference();
        for (let i = 0; i < 11; i++) {
            this.materials[i] = new Reference();
        }
    }
    load(stream, version, index) {
        this.version = version;
        this.modelName.load(stream, index);
        this.flags = stream.readUint32();
        this.sequences.load(stream, index);
        this.stc.load(stream, index);
        this.stg.load(stream, index);
        this.unknown0 = stream.readFloat32();
        this.unknown1 = stream.readFloat32();
        this.unknown2 = stream.readFloat32();
        this.unknown3 = stream.readFloat32();
        this.sts.load(stream, index);
        this.bones.load(stream, index);
        this.numberOfBonesToCheckForSkin = stream.readUint32();
        this.vertexFlags = stream.readUint32();
        this.vertices.load(stream, index);
        this.divisions.load(stream, index);
        this.boneLookup.load(stream, index);
        this.boundings.load(stream);
        stream.readUint32Array(this.unknown4To20);
        this.attachmentPoints.load(stream, index);
        this.attachmentPointAddons.load(stream, index);
        this.ligts.load(stream, index);
        this.shbxData.load(stream, index);
        this.cameras.load(stream, index);
        this.unknown21.load(stream, index);
        this.materialReferences.load(stream, index);
        for (let i = 0; i < 7; i++) {
            this.materials[i].load(stream, index); // Standard, Displacement, Composite, Terrain, Volume, ?, Creep
        }
        if (version > 24) {
            this.materials[7].load(stream, index); // Volume noise
        }
        if (version > 25) {
            this.materials[8].load(stream, index); // Splat terrain bake
        }
        if (version > 27) {
            this.materials[9].load(stream, index); // ?
        }
        if (version > 28) {
            this.materials[10].load(stream, index); // Lens flare
        }
        this.particleEmitters.load(stream, index);
        this.particleEmitterCopies.load(stream, index);
        this.ribbonEmitters.load(stream, index);
        this.projections.load(stream, index);
        this.forces.load(stream, index);
        this.warps.load(stream, index);
        this.unknown22.load(stream, index); // ?
        this.rigidBodies.load(stream, index);
        this.unknown23.load(stream, index); // ?
        this.physicsJoints.load(stream, index);
        if (version > 27) {
            this.clothBehavior.load(stream, index);
        }
        this.unknown24.load(stream, index); // ?
        this.ikjtData.load(stream, index);
        this.unknown25.load(stream, index); // ?
        if (version > 24) {
            this.unknown26.load(stream, index); // ?
        }
        this.partsOfTurrentBehaviors.load(stream, index);
        this.turrentBehaviors.load(stream, index);
        this.absoluteInverseBoneRestPositions.load(stream, index);
        this.tightHitTest.load(stream);
        this.fuzzyHitTestObjects.load(stream, index);
        this.attachmentVolumes.load(stream, index);
        this.attachmentVolumesAddon0.load(stream, index);
        this.attachmentVolumesAddon1.load(stream, index);
        this.billboardBehaviors.load(stream, index);
        this.tmdData.load(stream, index);
        this.unknown27 = stream.readUint32(); // ?
        this.unknown28.load(stream, index); // ?
    }
}
//# sourceMappingURL=modelheader.js.map