import Reference from './reference';
import { Float32AnimationReference, Uint32AnimationReference } from './animationreference';
/**
 * A standard material.
 */
export default class StandardMaterial {
    constructor() {
        this.version = -1;
        this.name = new Reference();
        this.additionalFlags = 0;
        this.flags = 0;
        this.blendMode = 0;
        this.priority = 0;
        this.usedRTTChannels = 0;
        this.specularity = 0;
        this.depthBlendFalloff = 0;
        this.cutoutThreshold = 0;
        this.unknown1 = 0;
        this.unknown2 = 0;
        this.unknown3 = 0;
        this.specMult = 0;
        this.emisMult = 0;
        this.diffuseLayer = new Reference();
        this.decalLayer = new Reference();
        this.specularLayer = new Reference();
        this.glossLayer = new Reference();
        this.emissiveLayer = new Reference();
        this.emissive2Layer = new Reference();
        this.evioLayer = new Reference();
        this.evioMaskLayer = new Reference();
        this.alphaMaskLayer = new Reference();
        this.alphaMask2Layer = new Reference();
        this.normalLayer = new Reference();
        this.heightLayer = new Reference();
        this.lightMapLayer = new Reference();
        this.ambientOcclusionLayer = new Reference();
        this.unknown4 = new Reference();
        this.unknown5 = new Reference();
        this.unknown6 = new Reference();
        this.unknown7 = new Reference();
        this.unknown8 = 0;
        this.layerBlendType = 0;
        this.emisBlendType = 0;
        this.emisMode = 0;
        this.specType = 0;
        this.unknown9 = new Float32AnimationReference();
        this.unknown10 = new Uint32AnimationReference();
        this.unknown11 = new Uint8Array(12);
    }
    load(stream, version, index) {
        this.version = version;
        this.name.load(stream, index);
        this.additionalFlags = stream.readUint32();
        this.flags = stream.readUint32();
        this.blendMode = stream.readUint32();
        this.priority = stream.readInt32();
        this.usedRTTChannels = stream.readUint32();
        this.specularity = stream.readFloat32();
        this.depthBlendFalloff = stream.readFloat32();
        this.cutoutThreshold = stream.readUint8();
        this.unknown1 = stream.readUint8(); // ?
        this.unknown2 = stream.readUint8(); // ?
        this.unknown3 = stream.readUint8(); // ?
        this.specMult = stream.readFloat32();
        this.emisMult = stream.readFloat32();
        this.diffuseLayer.load(stream, index);
        this.decalLayer.load(stream, index);
        this.specularLayer.load(stream, index);
        if (version > 15) {
            this.glossLayer.load(stream, index);
        }
        this.emissiveLayer.load(stream, index);
        this.emissive2Layer.load(stream, index);
        this.evioLayer.load(stream, index);
        this.evioMaskLayer.load(stream, index);
        this.alphaMaskLayer.load(stream, index);
        this.alphaMask2Layer.load(stream, index);
        this.normalLayer.load(stream, index);
        this.heightLayer.load(stream, index);
        this.lightMapLayer.load(stream, index);
        this.ambientOcclusionLayer.load(stream, index);
        if (version > 18) {
            this.unknown4.load(stream, index); // Unknown layer
            this.unknown5.load(stream, index); // Unknown layer
            this.unknown6.load(stream, index); // Unknown layer
            this.unknown7.load(stream, index); // Unknown layer
        }
        this.unknown8 = stream.readUint32(); // ?
        this.layerBlendType = stream.readUint32();
        this.emisBlendType = stream.readUint32();
        this.emisMode = stream.readUint32();
        this.specType = stream.readUint32();
        this.unknown9.load(stream); // ?
        this.unknown10.load(stream); // ?
        if (version > 18) {
            this.unknown11 = stream.readUint8Array(this.unknown11); // ?
        }
    }
}
//# sourceMappingURL=standardmaterial.js.map