import MdlxModel from '../../../parsers/mdlx/model';
import MdlxTexture from '../../../parsers/mdlx/texture';
import MdlxMaterial from '../../../parsers/mdlx/material';
import MdlxLayer from '../../../parsers/mdlx/layer';
import MdlxGeoset from '../../../parsers/mdlx/geoset';
import MdlxGeosetAnimation from '../../../parsers/mdlx/geosetanimation';
import MdlxBone from '../../../parsers/mdlx/bone';
export default function createPrimitive(viewer, primitive, material) {
    let lines;
    let color;
    let texture;
    let layerFlags = 1 /* Unshaded */;
    if (material) {
        lines = material.lines;
        color = material.color;
        texture = material.texture;
        if (material.twoSided) {
            layerFlags |= 16 /* TwoSided */;
        }
    }
    const model = new MdlxModel();
    // Extent
    const extent = model.extent;
    const r = primitive.boundingRadius;
    extent.min.fill(-r);
    extent.max.fill(r);
    extent.boundsRadius = r;
    // Texture
    const tex = new MdlxTexture();
    tex.path = 'PLACEHOLDER';
    model.textures[0] = tex;
    const pathSolver = (src) => {
        if (src === model) {
            return model;
        }
        return texture;
    };
    // Material
    const mat = new MdlxMaterial();
    const layer = new MdlxLayer();
    layer.textureId = 0;
    layer.flags = layerFlags;
    mat.layers[0] = layer;
    model.materials[0] = mat;
    // Geoset
    const geoset = new MdlxGeoset();
    geoset.vertices = primitive.vertices;
    geoset.uvSets[0] = primitive.uvs;
    geoset.matrixGroups = new Uint32Array([1]);
    geoset.matrixIndices = new Uint32Array([0]);
    geoset.vertexGroups = new Uint8Array(primitive.vertices.length / 3);
    let faceTypeGroup = 4;
    let indices = primitive.faces;
    if (lines) {
        faceTypeGroup = 1;
        indices = primitive.edges;
    }
    geoset.faceTypeGroups = new Uint32Array([faceTypeGroup]);
    geoset.faceGroups = new Uint32Array([indices.length]);
    geoset.faces = indices;
    model.geosets[0] = geoset;
    // Color via a geoset animation.
    if (color) {
        const geosetAnimation = new MdlxGeosetAnimation();
        geosetAnimation.geosetId = 0;
        geosetAnimation.color = color;
        model.geosetAnimations[0] = geosetAnimation;
    }
    // Bone - otherwise can't transform the instance.
    const bone = new MdlxBone();
    bone.objectId = 0;
    model.bones[0] = bone;
    // Load and return the promise.
    return viewer.load(model, pathSolver);
}
//# sourceMappingURL=createprimitive.js.map