import { vec3 } from 'gl-matrix';
import { VEC3_ZERO, VEC3_ONE, QUAT_DEFAULT } from '../../../common/gl-matrix-addon';
import AnimatedObject from './animatedobject';
/**
 * An MDX generic object.
 */
export default class GenericObject extends AnimatedObject {
    constructor(model, object, index) {
        super(model, object);
        this.index = index;
        this.name = object.name;
        this.objectId = object.objectId;
        this.parentId = object.parentId;
        this.pivot = model.pivotPoints[object.objectId] || vec3.create();
        const flags = object.flags;
        this.dontInheritTranslation = flags & 1 /* DontInheritTranslation */;
        this.dontInheritRotation = flags & 2 /* DontInheritRotation */;
        this.dontInheritScaling = flags & 4 /* DontInheritScaling */;
        this.billboarded = flags & 8 /* Billboarded */;
        this.billboardedX = flags & 16 /* BillboardedLockX */;
        this.billboardedY = flags & 32 /* BillboardedLockY */;
        this.billboardedZ = flags & 64 /* BillboardedLockZ */;
        this.cameraAnchored = flags & 128 /* CameraAnchored */;
        this.anyBillboarding = (this.billboarded || this.billboardedX || this.billboardedY || this.billboardedZ) !== 0;
        if (object.objectId === object.parentId) {
            this.parentId = -1;
        }
        this.addVariants('KGTR', 'translation');
        this.addVariants('KGRT', 'rotation');
        this.addVariants('KGSC', 'scale');
        this.addVariantIntersection(['translation', 'rotation', 'scale'], 'generic');
    }
    /**
     * Give a consistent visibility getter for all generic objects.
     *
     * Many of the generic objects have animated visibilities, and will override this.
     */
    getVisibility(out, sequence, frame, counter) {
        out[0] = 1;
        return -1;
    }
    getTranslation(out, sequence, frame, counter) {
        return this.getVectorValue(out, 'KGTR', sequence, frame, counter, VEC3_ZERO);
    }
    getRotation(out, sequence, frame, counter) {
        return this.getQuatValue(out, 'KGRT', sequence, frame, counter, QUAT_DEFAULT);
    }
    getScale(out, sequence, frame, counter) {
        return this.getVectorValue(out, 'KGSC', sequence, frame, counter, VEC3_ONE);
    }
}
//# sourceMappingURL=genericobject.js.map